# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.organisation_document import OrganisationDocument  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestOrganisationDocument(unittest.TestCase):
    """OrganisationDocument unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OrganisationDocument
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganisationDocument`
        """
        model = empire_platform_api_public_client.models.organisation_document.OrganisationDocument()  # noqa: E501
        if include_optional :
            return OrganisationDocument(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                file_type = 'IMAGE', 
                description = '', 
                uploaded_at = '2022-01-04T00:00Z', 
                uploaded_by_user = empire_platform_api_public_client.models.organisation_document_uploaded_by_user.OrganisationDocument_uploadedByUser(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    name = '', 
                    organisation = empire_platform_api_public_client.models.aggregated_nomination_options_nominee_participants_inner.AggregatedNominationOptions_nomineeParticipants_inner(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        name = '', ), ), 
                status = 'UPLOADED', 
                attachment = empire_platform_api_public_client.models.attachment.Attachment(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    file_name = '', 
                    file_size = 0, 
                    mime_type = '', 
                    url = '', )
            )
        else :
            return OrganisationDocument(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                file_type = 'IMAGE',
                description = '',
                uploaded_at = '2022-01-04T00:00Z',
                uploaded_by_user = empire_platform_api_public_client.models.organisation_document_uploaded_by_user.OrganisationDocument_uploadedByUser(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    name = '', 
                    organisation = empire_platform_api_public_client.models.aggregated_nomination_options_nominee_participants_inner.AggregatedNominationOptions_nomineeParticipants_inner(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        name = '', ), ),
                status = 'UPLOADED',
        )
        """

    def testOrganisationDocument(self):
        """Test OrganisationDocument"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.dashboard_next_nomination_gate import DashboardNextNominationGate  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestDashboardNextNominationGate(unittest.TestCase):
    """DashboardNextNominationGate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DashboardNextNominationGate
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DashboardNextNominationGate`
        """
        model = empire_platform_api_public_client.models.dashboard_next_nomination_gate.DashboardNextNominationGate()  # noqa: E501
        if include_optional :
            return DashboardNextNominationGate(
                timescale = 'LONG_TERM', 
                window = empire_platform_api_public_client.models.dashboard_next_nomination_gate_window.DashboardNextNominationGate_window(
                    opens_at = '2022-01-04T00:00Z', 
                    closes_at = '2022-01-04T00:00Z', ), 
                delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                    from_mtu_start = '2022-01-04T10:00Z', 
                    to_mtu_end = '2022-01-04T11:00Z', ), 
                status = 'NOT_YET_OPEN', 
                next_action_at = '2022-01-04T00:00Z'
            )
        else :
            return DashboardNextNominationGate(
                timescale = 'LONG_TERM',
                window = empire_platform_api_public_client.models.dashboard_next_nomination_gate_window.DashboardNextNominationGate_window(
                    opens_at = '2022-01-04T00:00Z', 
                    closes_at = '2022-01-04T00:00Z', ),
                delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                    from_mtu_start = '2022-01-04T10:00Z', 
                    to_mtu_end = '2022-01-04T11:00Z', ),
                status = 'NOT_YET_OPEN',
                next_action_at = '2022-01-04T00:00Z',
        )
        """

    def testDashboardNextNominationGate(self):
        """Test DashboardNextNominationGate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class OrganisationDocumentFileType(str, Enum):
    """
    See mapping of MIME Types at `uploadAttachment` endpoint 
    """

    """
    allowed enum values
    """
    IMAGE = 'IMAGE'
    DOCUMENT = 'DOCUMENT'
    TEXT = 'TEXT'
    ARCHIVE = 'ARCHIVE'

    @classmethod
    def from_json(cls, json_str: str) -> OrganisationDocumentFileType:
        """Create an instance of OrganisationDocumentFileType from a JSON string"""
        return OrganisationDocumentFileType(json.loads(json_str))





# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.day_ahead_auction import DayAheadAuction  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestDayAheadAuction(unittest.TestCase):
    """DayAheadAuction unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DayAheadAuction
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DayAheadAuction`
        """
        model = empire_platform_api_public_client.models.day_ahead_auction.DayAheadAuction()  # noqa: E501
        if include_optional :
            return DayAheadAuction(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                name = '2022 May Auction', 
                display_id = 'BDL-NL-GB-E-BASE---220305-01', 
                product_type = 'LT_EXPLICIT_MULTI_ANNUAL', 
                border_direction = 'GB_NL', 
                status = 'CREATED', 
                processing = True, 
                delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                    from_mtu_start = '2022-01-04T10:00Z', 
                    to_mtu_end = '2022-01-04T11:00Z', ), 
                allocation_mtu_size = 'MTU_15_MINS', 
                allocation_resolution = 'RES_1_KW', 
                bidding_configuration = empire_platform_api_public_client.models.auction_bidding_configuration.AuctionBiddingConfiguration(
                    mode = 'OPEN', 
                    pre_bidding_allowed = True, 
                    max_bids_per_participants = 0, 
                    min_bid_price = 1.337, ), 
                process_steps = empire_platform_api_public_client.models.auction_process_steps_absolute.AuctionProcessStepsAbsolute(
                    preliminary_spec_publish = '2022-01-04T00:00Z', 
                    returns_window_close = '2022-01-04T00:00Z', 
                    final_spec_publish = '2022-01-04T00:00Z', 
                    bidding_open = '2022-01-04T00:00Z', 
                    show_bids_for_open_auctions = '2022-01-04T00:00Z', 
                    bidding_close = '2022-01-04T00:00Z', 
                    provisional_results_publish = '2022-01-04T00:00Z', 
                    final_results_publish = '2022-01-04T00:00Z', ), 
                offered_capacity_setup = 'PERCENT_100_ATC', 
                mtus = [
                    empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_mtu.DayAheadOrIntraDayAuctionMtu(
                        mtu = '2022-01-04T10:00Z', 
                        atc = 56, 
                        preliminary_oc = 56, 
                        un_nominated_capacity = 56, 
                        final_oc = 56, )
                    ]
            )
        else :
            return DayAheadAuction(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                name = '2022 May Auction',
                display_id = 'BDL-NL-GB-E-BASE---220305-01',
                product_type = 'LT_EXPLICIT_MULTI_ANNUAL',
                border_direction = 'GB_NL',
                status = 'CREATED',
                processing = True,
                delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                    from_mtu_start = '2022-01-04T10:00Z', 
                    to_mtu_end = '2022-01-04T11:00Z', ),
                allocation_mtu_size = 'MTU_15_MINS',
                allocation_resolution = 'RES_1_KW',
                bidding_configuration = empire_platform_api_public_client.models.auction_bidding_configuration.AuctionBiddingConfiguration(
                    mode = 'OPEN', 
                    pre_bidding_allowed = True, 
                    max_bids_per_participants = 0, 
                    min_bid_price = 1.337, ),
                process_steps = empire_platform_api_public_client.models.auction_process_steps_absolute.AuctionProcessStepsAbsolute(
                    preliminary_spec_publish = '2022-01-04T00:00Z', 
                    returns_window_close = '2022-01-04T00:00Z', 
                    final_spec_publish = '2022-01-04T00:00Z', 
                    bidding_open = '2022-01-04T00:00Z', 
                    show_bids_for_open_auctions = '2022-01-04T00:00Z', 
                    bidding_close = '2022-01-04T00:00Z', 
                    provisional_results_publish = '2022-01-04T00:00Z', 
                    final_results_publish = '2022-01-04T00:00Z', ),
                offered_capacity_setup = 'PERCENT_100_ATC',
        )
        """

    def testDayAheadAuction(self):
        """Test DayAheadAuction"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Union
from pydantic import BaseModel, Field, confloat, conint

class AuctionResultCongestionRent(BaseModel):
    """
    * `ocRevenue` - Revenue materialised from selling the OC at marginal price * `returnsRevenue` - Revenue materialised from returns * `totalRevenue` - All revenues summed up 
    """
    oc_revenue: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(..., alias="ocRevenue", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    returns_revenue: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(..., alias="returnsRevenue", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    total_revenue: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(..., alias="totalRevenue", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    __properties = ["ocRevenue", "returnsRevenue", "totalRevenue"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AuctionResultCongestionRent:
        """Create an instance of AuctionResultCongestionRent from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AuctionResultCongestionRent:
        """Create an instance of AuctionResultCongestionRent from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AuctionResultCongestionRent.parse_obj(obj)

        _obj = AuctionResultCongestionRent.parse_obj({
            "oc_revenue": obj.get("ocRevenue"),
            "returns_revenue": obj.get("returnsRevenue"),
            "total_revenue": obj.get("totalRevenue")
        })
        return _obj

